# Library Reference - Visualisation Tools

## Comments

Input comments into the pipeline.

## Nexus File Viewer for I16

Diamond Light Source Nexus File Viewer for Beamline I16

## Laxarus Viewer

Laxarus XRD Imaging HDF5 Viewer.

## View Array

Render an image of the two or three-dimensional input Numpy array to the Visualisation tab.

Parameters:

Input file

  User provided path string to the input NumPy file.

Type

  - Amplitude - An iso-surface of the array amplitude.

  - Phase - An interactive scalar cut plane of the array phase.

  - Amplitude and Phase - An iso-surface of the array amplitude and an interactive scalar cut plane of the array phase.

  - Amplitude with Phase - An iso-surface of the array amplitude with the array phase mapped onto the iso-surface.

  - Amplitude (cut plane) - An interactive scalar cut plane of the array amplitude.

Amplitude

  - Iso-surface - Scalar value for the rendered iso-surface.

  - Opacity - Opacity of the isosurface when viewing `Amplitude and Phase`.

  - Feature angle - Minimum angle between two surface normals of the rendered object.

Phase

  - Max - Maximum phase.

  - Min - Minimum phase.

Origin

  Origin point of the interactive scalar cut plane.

Normal

  Normal vector to the interactive scalar cut plane.

Spacing

  Spacing of the input array indices.

View Axes

  Optionally view the axes of the array.

## View Object

Render an object of the three-dimensional input Numpy array with it’s corresponding co-ordinates array to the Visualisation tab.

Parameters:

Input file

  User provided path string to the input NumPy file.

Co-ord’s File

  User provided path string to the corresponding co-ordinates NumPy array file. Alternatively, the memory array keyword `memorycoords` provides access to the internally stored coordinate array. Generating a coordinate array is achieved using the Coordinate transformation operation.

Type

  - Amplitude - An iso-surface of the object amplitude.

  - Phase - An interactive scalar cut plane of the object phase.

  - Amplitude and Phase - An iso-surface of the object amplitude and an interactive scalar cut plane of the object phase.

  - Amplitude with Phase - An iso-surface of the object amplitude with the object phase mapped onto the iso-surface.

  - Amplitude (cut plane) - An interactive scalar cut plane of the object amplitude.

Amplitude

  - Iso-surface - Scalar value for the rendered iso-surface.

  - Opacity - Opacity of the isosurface when viewing `Amplitude and Phase`.

  - Feature angle - Minimum angle between two surface normals of the rendered object.

Phase

  - Max - Maximum phase.

  - Min - Minimum phase.

Origin

  Origin point of the interactive scalar cut plane.

Normal

  Normal vector to the interactive scalar cut plane.

View Axes

  Optionally view the axes of the object.

## View Support

Render an image of a three-dimensional input Numpy data array and its Support array to the Visualisation tab.

Parameters:

Support file

  User provided path string to the NumPy array file.

Data array file

  User provided path string to the NumPy array file.

Isosurface options

  - Support iso-surface - Scalar value for the rendered iso-surface on the interval [0,1].

  - Opacity - Opacity of the support isosurface.

  - Data file iso-surface - Scalar value for the rendered iso-surface.

  - Feature angle - Minimum angle between two surface normals of the rendered object.

View Axes

  Optionally view the axes of the array.

## View VTK Array

Render an input VTK array to the Visualisation tab.

Parameters:

Input file

  User provided path string to the input NumPy file.

Type

  - Amplitude - An iso-surface of the array amplitude.

  - Phase - An interactive scalar cut plane of the array phase.

  - Amplitude (cut plane) - An interactive scalar cut plane of the array amplitude.

Amplitude

  - Iso-surface - Scalar value for the rendered iso-surface.

  - Feature angle - Minimum angle between two surface normals of the rendered object.

Phase

  - Max - Maximum phase.

  - Min - Minimum phase.

Origin

  Origin point of the interactive scalar cut plane.

Normal

  Normal vector to the interactive scalar cut plane.

View Axes

  Optionally view the axes of the array.